DicomWebClient

Struct DicomWebClient 

pub struct DicomWebClient { /* private fields */ }
The DICOMweb client for querying and retrieving DICOM objects. Can be reused for multiple requests.

Implementations

Source

impl DicomWebClient

pub fn query_modality_scheduled_procedure_steps(&self) -> MwlRequest

Create a DMWL-RS request to query all studies

Source

impl DicomWebClient

pub fn query_studies(&self) -> QidoRequest

Create a QIDO-RS request to query all studies

pub fn query_series(&self) -> QidoRequest

Create a QIDO-RS request to query all series

pub fn query_series_in_study(&self, study_instance_uid: &str) -> QidoRequest

Create a QIDO-RS request to query all series in a specific study

pub fn query_instances(&self) -> QidoRequest

Create a QIDO-RS request to query all instances

pub fn query_instances_in_series( &self, study_instance_uid: &str, series_instance_uid: &str, ) -> QidoRequest

Create a QIDO-RS request to query all instances in a specific series

Source

impl DicomWebClient

pub fn store_instances(&self) -> WadoStowRequest

Create a STOW-RS request to store instances

pub fn store_instances_in_study( &self, study_instance_uid: &str, ) -> WadoStowRequest

Create a WADO-RS request to retrieve the metadata of a specific study

Source

impl DicomWebClient

pub fn retrieve_study(&self, study_instance_uid: &str) -> WadoFileRequest

Create a WADO-RS request to retrieve a specific study

pub fn retrieve_study_metadata( &self, study_instance_uid: &str, ) -> WadoMetadataRequest

Create a WADO-RS request to retrieve the metadata of a specific study

pub fn retrieve_series( &self, study_instance_uid: &str, series_instance_uid: &str, ) -> WadoFileRequest

Create a WADO-RS request to retrieve a specific series

pub fn retrieve_series_metadata( &self, study_instance_uid: &str, series_instance_uid: &str, ) -> WadoMetadataRequest

Create a WADO-RS request to retrieve the metadata of a specific series

pub fn retrieve_instance( &self, study_instance_uid: &str, series_instance_uid: &str, sop_instance_uid: &str, ) -> WadoSingleFileRequest

Create a WADO-RS request to retrieve a specific instance

pub fn retrieve_instance_metadata( &self, study_instance_uid: &str, series_instance_uid: &str, sop_instance_uid: &str, ) -> WadoMetadataRequest

Create a WADO-RS request to retrieve the metadata of a specific instance

pub fn retrieve_frames( &self, study_instance_uid: &str, series_instance_uid: &str, sop_instance_uid: &str, framelist: &[u32], ) -> WadoFramesRequest

Create a WADO-RS request to retrieve specific frames inside an instance

Source

impl DicomWebClient

pub fn set_basic_auth(&mut self, username: &str, password: &str) -> &Self

Set the basic authentication for the DICOMWeb client. Will be passed in the Authorization header.

pub fn set_bearer_token(&mut self, token: &str) -> &Self

Set the bearer token for the DICOMWeb client. Will be passed in the Authorization header.

pub fn add_header(&mut self, key: &str, value: &str) -> &Self

pub fn with_single_url(url: &str) -> DicomWebClient

Create a new DICOMWeb client with the same URL for all services (WADO-RS, QIDO-RS, STOW-RS).

pub fn with_separate_urls( wado_url: &str, qido_url: &str, stow_url: &str, ) -> DicomWebClient

Create a new DICOMWeb client with separate URLs for each service.